/*
* [IsJetExe.java]
*
* Summary: Determines if a file is a Jet executable. Searches the Java library path for file mentioned on the command line.
*
* Copyright: (c) 2011-2014 Roedy Green, Canadian Mind Products, http://mindprod.com
*
* Licence: This software may be copied and used freely for any purpose but military.
*          http://mindprod.com/contact/nonmil.html
*
* Requires: JDK 1.5+
*
* Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
*
* Version History:
*  1.0  2011-12-28 initial version.
*/
package com.mindprod.common15;

import java.io.File;
import java.io.FilenameFilter;
import java.util.regex.Pattern;

import static java.lang.System.err;
import static java.lang.System.out;

/**
 * NOT JET COMPLETE:
 *
 * Determines if a file is a Jet executable. Searches the Java library path for file mentioned on the command line.
 * I composed this program is a dream, waking up a dozen times
 * to discover I had not hit a single keystroke.   I compose this
 * not so much because I think anyone will need this, but because
 * I want to shut up the damn dream.
 * <p/>
 * Put file you want to examine on command line.
 * If it is a Jet exe will get 0 as the retCode.
 * If it is a standard exe, you will yet a 1 as the retCode.
 * If it cannot find the file, you will get a 2.
 * If you mad a syntax error, you will get a 3.
 *
 *
 * Will also allow *.jar and *.class which will search classpath.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2011-12-28 initial version.
 * @since 2011-12-28
 */
public class IsJetExe
    {
    /** used to split out various legs of the path */
    private static Pattern SPLITTER = Pattern.compile( System.getProperty( "path.separator" ) );

    /** how to use this utility.*/
    private static String USAGE = "IsJetExe someprog.exe (where somefile.exe is on the path).";

    // --------------------------- main() method ---------------------------

    /**
     * Determine if a file in an ordinary exe or a Jet exe.
     * @param args  name of an exe file to be found somewhere on the path
     */
    public static void main( String[] args )
        {

        if ( args.length != 1 )
            {
            err.println( "Must have exactly one file on the command line.\n" + USAGE );
            System.exit( 3 );
            }
        final String fileToExamine = args[ 0 ];
        final String path = System.getProperty( "java.library.path" );

        if ( path != null )
            {
            String[] legs = SPLITTER.split( path );
            boolean first = true;
            for ( String leg : legs )
                {
                // no jars on path, just dirs.
                File dir = new File( leg );
                if ( !dir.isDirectory() )
                    {
                    err.println( "Warning: non dir [" + leg + "] found on path" );
                    continue;
                    }
                String[] candidates = dir.list( new OnlyExes() );
                for ( String candidate : candidates )
                    {
                    if ( fileToExamine.equalsIgnoreCase( candidate ) )

                        {
                        File hit = new File( dir, candidate );

                        out.println( ( first ? "first " : "" ) + "found " + hit.getAbsolutePath() );
                        first = false;
                        }
                    }
                }
            }
        }
    }

/**
 * just Exe file, no directories.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2011-12-28 initial version.
 * @since 2011-12-28
 */
 final class OnlyExes implements FilenameFilter// note Sun's
        // spelling, not
        // FileNameFilter
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * Select only Files with an extension in our want list
     *
     * @param dir  the directory in which the file was found.
     * @param name the name of the file
     *
     * @return true if and only if the name should be included in the file list; false otherwise.
     */
    public boolean accept( File dir, String name )
        {
        System.getProperties().list( System.out );
        File f = new File( dir, name );
        if ( f.isDirectory() )
            {
            return false;
            }
        // strip out the extension.
        int place = name.lastIndexOf( '.' );
        if ( place < 0 )
            {
            return false;
            }
        // get just stuff past the dot to the end
        String ext = name.substring( place + 1 );
        return ext.toLowerCase().equals( "exe" );
        }
    }
