/*
 * [Warn.java]
 *
 * Summary: Displays a single line warning that can only be dismissed by hitting Acknowledge.
 *
 * Copyright: (c) 1999-2014 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.6+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 1999-01-01 initial version.
 */
package com.mindprod.setclock;

import java.awt.Button;
import java.awt.Dialog;
import java.awt.Frame;
import java.awt.Label;

/**
 * Displays a single line warning that can only be dismissed by hitting Acknowledge.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 1999-01-01 initial version.
 * @since 1999
 */
@SuppressWarnings({ "FieldCanBeLocal" })
final class Warn extends Dialog implements java.awt.event.ActionListener
    {
    // ------------------------------ FIELDS ------------------------------

    /**
     * dismiss the warning
     */
    private final Button okButton;

    /**
     * displays text of the warning
     */
    private final Label warningLabel;

    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * Display a warning box
     *
     * @param parent  parent, usually the Applet
     * @param title   title for the box
     * @param warning text of the warning message
     */
    public Warn( Frame parent, String title, String warning )
        {
        super( parent, title, true );
        warningLabel = new Label( warning );
        this.add( warningLabel );
        okButton = new Button( "Acknowledge" );
        this.add( okButton );
        okButton.addActionListener( this );
        validate();
        setVisible( true );
        }// end constructor

    /**
     * Handle Button Push
     *
     * @param e details of just what the user clicked.
     */
    public void actionPerformed( java.awt.event.ActionEvent e )
        {
        Object object = e.getSource();
        if ( object == okButton )
            {
            this.setVisible( false );
            this.dispose();
            }
        }// end actionPerformed
    }
